@@ -22,7 +22,23 @@ sub headers { $_[0]->{headers} }
 sub finalize {
     my $self = shift;
     delete $self->{headers};
-    return delete $self->{code}
+
+    # Defence from HTTP Header Splitting.
+    my $code = delete $self->{code};
+    return sub {
+        my $responder = shift;
+        $code->(
+            sub {
+                my @copy = @{ $_[0]->[1] };
+                for (my ($key, $val) = splice(@copy, 0, 2)) {
+                    if ($val =~ /[\000-\037]/) {
+                        die("Response headers MUST NOT contain characters below octal \037\n");
+                    }
+                }
+                return $responder->(@_);
+            }
+        );
+    };
 }
 
 
